@@ -220,7 +220,9 @@ class SpeechMixSelf(SpeechMixEED):
         if input_ids is not None:
             nlp_hidden = \
                 self.decoder_model(input_ids.to(self.device), output_hidden_states=True)['encoder_hidden_states'][0]
-            attn_output = torch.bmm(nlp_hidden, projected_embeds.view(1, self.decoder_model.config.hidden_size, -1))
+            attn_output = torch.bmm(nlp_hidden,
+                                    projected_embeds.view(nlp_hidden.shape[0], self.decoder_model.config.hidden_size,
+                                                          -1))
             voice_projected_embeds = torch.bmm(attn_output, projected_embeds)
 
             kld_outputs = self.decoder_model(input_ids.to(self.device),
